@@ -1,4 +1,4 @@
-# Copyright (C) 2021 Brodie Gaslam
+# Copyright (C) 2022 Brodie Gaslam
 #
 # This file is part of "unitizer"
 #
@@ -142,31 +142,33 @@ setMethod(
       # before re-eval
 
       if(!is.null(x@bookmark)) {
-        cand.match <- which(x@bookmark@call == x@items.new.calls.deparse)
-        cand.match.len <- length(cand.match)
-        if(!cand.match.len || x@bookmark@id > cand.match.len) {
-          meta_word_msg(
-            cc(
-              "Unable to find test you toggled re-eval from; starting ",
-              "from beginning."
-          ) )
-        } else {
-          match.id <- cand.match[x@bookmark@id]
-          id.map <-
-            which(y@mapping@item.id.orig == match.id & !y@mapping@item.ref)
-          if(!length(id.map) == 1L) {
-            # nocov start
-            stop(
-              "Internal Error: unable to find bookmarked test; contact ",
-              "maintainer."
-            )
-            # nocov end
-          }
-          ign.adj <- find_lead_offset(id.map, y@mapping)
-          y@last.id <- y@mapping@item.id[id.map] - (1L + ign.adj)
-          y@jumping.to <- id.map
-        }
-      }
+        # NA bookmark just means start from beginning (don't set jumping.to).
+        # Used to have a subset of all the unitizes in a directory re-reviewed
+        if(!is.na(x@bookmark@call)) {
+          cand.match <- which(x@bookmark@call == x@items.new.calls.deparse)
+          cand.match.len <- length(cand.match)
+          if(!cand.match.len || x@bookmark@id > cand.match.len) {
+            meta_word_msg(
+              cc(
+                "Unable to find test you toggled re-eval from; starting ",
+                "from beginning."
+            ) )
+          } else {
+            match.id <- cand.match[x@bookmark@id]
+            id.map <-
+              which(y@mapping@item.id.orig == match.id & !y@mapping@item.ref)
+            if(!length(id.map) == 1L) {
+              # nocov start
+              stop(
+                "Internal Error: unable to find bookmarked test; contact ",
+                "maintainer."
+              )
+              # nocov end
+            }
+            ign.adj <- find_lead_offset(id.map, y@mapping)
+            y@last.id <- y@mapping@item.id[id.map] - (1L + ign.adj)
+            y@jumping.to <- id.map
+      } } }
       # `repeat` loop allows us to keep going if at the last minute we decide
       # we are not ready to exit the unitizer
 
@@ -449,7 +451,7 @@ setMethod(
     unitizer <- new(
       "unitizer", id=x@id, changes=x@changes, zero.env=x@zero.env,
       base.env=x@base.env, test.file.loc=x@test.file.loc,
-      state.ref=state.merged$states
+      state.ref=state.merged$states, global=x@global
     )
     unitizer <- unitizer + state.merged$items
 
@@ -717,13 +719,7 @@ setMethod("reviewNext", c("unitizerBrowse"),
         )
         cat("\n")
       }
-      parsed.call <- try(parse(text=item.main@call.dep)[[1L]])
-      if(inherits(parsed.call, "try-error")) {
-        # nocov start
-        stop("Internal Error: malformed call stored; contact maintainer.")
-        # nocov end
-      }
-      cat(deparse_prompt(parsed.call), sep="\n")
+      cat(deparse_prompt(item.main), sep="\n")
       history_write(x@hist.con, item.main@call.dep)
 
       # show the message, and set the trace if relevant; options need to be
@@ -752,7 +748,7 @@ setMethod("reviewNext", c("unitizerBrowse"),
             stderr()
           )
           out.err <- TRUE
-        }
+        } 
         if(length(item.main@trace)) set_trace(item.main@trace)
       }
       # If test failed, show details of failure; note this should mean there
@@ -814,8 +810,25 @@ setMethod("reviewNext", c("unitizerBrowse"),
 
         if(!is.null(diffs@state)) diffs@state@show.diff <- TRUE
 
-      } else if (out.std || out.err) cat("\n")
-    }
+      }
+      else if (out.std || out.err) cat("\n")
+      else if (!item.main@ignore && length(item.main@data@conditions)) {
+        # No visible output, but conditions issued.  Say something as otherwise
+        # confusing why unitizer prompt appears.
+        cat("\n")
+        meta_word_cat(
+          paste0(
+            "Test ", if(!unitizer@transcript) "silently ",
+            "signalled conditions (use ", "e.g. .",
+            if(item.main@reference) "REF" else "NEW",
+            "$conditions[[1]] to inspect):\n"
+        ) )
+        screen_out(
+          capture.output(show(item.main@data@conditions)),
+          max.len=unitizer@global$unitizer.opts[["unitizer.test.out.lines"]]
+        )
+        cat("\n")
+    } }
 
     if(!will.review) return(x)
 
@@ -824,7 +837,9 @@ setMethod("reviewNext", c("unitizerBrowse"),
 
     if(!x@interactive) {   # can't proceed in non-interactive
       x@interactive.error <- TRUE
-      invokeRestart("unitizerEarlyExit", extra=x)
+      x@mapping@reviewed[curr.id] <- TRUE
+      x@mapping@review.val[curr.id] <- 'N'
+      return(x)
     }
     x@human <- TRUE
 
